from __future__ import unicode_literals

from django.utils.encoding import python_2_unicode_compatible
from django_extensions.db.models import TimeStampedModel
from django.db import models


@python_2_unicode_compatible
class ElectionResults(TimeStampedModel):
    """ """

    class ResultStatus:
        ERROR = 0
        EXTRACTION = 1
        SIGNATURE = 2
        COUNT = 3
        VERIFICATION = 4
        PUBLISHED = 5

        choices = (
            (ERROR, "Error generating results"),
            (EXTRACTION, "Extraction"),
            (SIGNATURE, "Decypher and signature"),
            (COUNT, "Count"),
            (VERIFICATION, "Final verification"),
            (PUBLISHED, "Results published"),
        )

    id = models.AutoField("id", primary_key=True)
    election_id = models.IntegerField(
        "election id", db_index=True,
        default=-1, editable=False,
        unique=True)
    result_status_choices = models.PositiveSmallIntegerField(
        "Current result status",
        choices=ResultStatus.choices,
        default=1,
        editable=False)
    election_results = models.TextField(
        "Election results in JSON format",
        default="",
        editable=False)
    worker_pid = models.IntegerField(
        "Worker thread PID generating the results",
        default=None,
        null=True,
        editable=False)

    class Meta:
        verbose_name = "Election Status"
        verbose_name_plural = "Elections Statuses"

    def __str__(self):
        return self.election_id
