from rest_framework import serializers
from .models import ElectionResults


class ResultsStatusSerializer(serializers.ModelSerializer):
    class Meta:
        model = ElectionResults
        fields = ('result_status_choices', )


class GenerateResultsSerializer(serializers.Serializer):
    vs_cert = serializers.CharField(
        required=True,
        allow_blank=False,
        help_text="Validator Service" +
                  " certificate" +
                  " in PEM format"
    )
    root_cert = serializers.CharField(
        required=True,
        allow_blank=False,
        help_text="Root certificate"
                  " in PEM format"
    )
    cs_pvt_key = serializers.CharField(
        required=True,
        allow_blank=False,
        help_text="Counter Service" +
                  " private key in" +
                  " PEM format"
    )
    election_pvt_key = serializers.CharField(
        required=True,
        allow_blank=False,
        help_text="Election certificate private key" +
                  " in PEM format"
    )
    sge_cert = serializers.CharField(
        required=True,
        allow_blank=False,
        help_text="Election Management System" +
                  " certificate in PEM format"
    )
    secret_list = serializers.ListField(
        required=True,
        help_text="List of shared secret keys",
        child=serializers.CharField(
            allow_blank=False
        )
    )
    elec_proc_id = serializers.IntegerField(
        required=True,
        help_text="Electoral process ID"
    )

    def validate(self, data):
        """
        Complete object validation.
        Access fields using array dictionary notation data['field']
        Errors should raise a ValidationError Exception
        """
        data = super(GenerateResultsSerializer, self).validate(data)

        return data
